==> haskell-hasql-1.4.5.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.4.5.2
visibility:           public
id:                   hasql-1.4.5.2-HUA4p2q2ztl9wXrKo8ikqn
key:                  hasql-1.4.5.2-HUA4p2q2ztl9wXrKo8ikqn
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  7bd7609910a8f9979e1fd9a1248641e3
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hasql-1.4.5.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hasql-1.4.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hasql-1.4.5.2
hs-libraries:         HShasql-1.4.5.2-HUA4p2q2ztl9wXrKo8ikqn
depends:
    attoparsec-0.14.1-FCw2YbaswCt6roS8dkagL4 base-4.15.0.0
    bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.4-KotoentFwV2Eq423pjyiJF
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    dlist-1.0-BmQe4lx0gldHtaeQvhsVhJ
    hashable-1.3.3.0-LgC2GKp34OLEabneGtyuCb
    hashtables-1.2.4.1-1sort5JioXoDrvb33CoEIT mtl-2.2.2
    postgresql-binary-0.12.4.1-LRMZJ8XnsjVCvRwIFYGz0N
    postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8
    profunctors-5.6.2-FuEKR7yDDqrCb6OWIkshes text-1.2.4.1
    text-builder-0.6.6.3-DHiS3Zs5OxF66c2Ze2JtoQ transformers-0.5.6.2
    vector-0.12.3.1-KJ02XewdvWJHGa2GVFsQSX

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.4.5.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql
version:              1.4.5.2
visibility:           public
id:                   hasql-1.4.5.2-DggjshYW6Dr5qDQGKjVdOL
key:                  hasql-1.4.5.2-DggjshYW6Dr5qDQGKjVdOL
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  7b2e6affc4d701b952fafc44718abbfa
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hasql-1.4.5.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hasql-1.4.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hasql-1.4.5.2
hs-libraries:         HShasql-1.4.5.2-DggjshYW6Dr5qDQGKjVdOL
depends:
    attoparsec-0.14.1-EcyJzfZhZzx4rFmzSXlwR7 base-4.15.0.0
    bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.4-7TttSVmXQCcB6B8eF6w3ai
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A
    dlist-1.0-4uSjbl72fpn9e2vwvg1nn4
    hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
    hashtables-1.2.4.1-CDao21uYnK7Ckjg39SiLrf mtl-2.2.2
    postgresql-binary-0.12.4.1-Cy5qytlsCkM7mUSyXQApiM
    postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8
    profunctors-5.6.2-FldYguYhNFh2EzXhmRbPBa text-1.2.4.1
    text-builder-0.6.6.3-FqcwDejkZLg485to9J5RcA transformers-0.5.6.2
    vector-0.12.3.1-7avVqi4S14u4vwRbDqmIKr

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
